@@ -1,4 +1,4 @@
-"""Things to do when the file is imported"""
+# Load CSV when file is imported:
 if __name__ != "__main__":
     import csv
 
@@ -12,13 +12,17 @@ if __name__ != "__main__":
 
     this_dir, this_filename = os.path.split(__file__)
     path = os.path.join(this_dir, "verbs.csv")
-    with open(path, "r", newline="") as file:
+    with open(path, "r", newline="", encoding="utf-8") as file:
         verblist = csv.reader(file)
         for row in verblist:
-            conjugations.append(row)
-            infinitives.append(row[0])
-
+            try:
+                conjugations.append(row)
+                infinitives.append(row[0])
+            except:
+                conjugations.append([])
+                infinitives.append("")
 
+# CSV indexing and searching methods
 def findIndex(verb: str):
     assert len(verb) > 0
     return infinitives.index(verb)
@@ -33,6 +37,7 @@ def findLine(verb: str):
     return line(findIndex(verb))
 
 
+# Formatting for those without german keyboard
 def format(word: str):
     if "^" not in word:
         return word
@@ -51,6 +56,7 @@ def format(word: str):
     return newwrt
 
 
+# All tenses conjugation:
 def present(verb: str, pronoun: str):
     temp = findLine(verb)
     return temp[tense_conj[pronoun]]
@@ -76,6 +82,7 @@ def future(verb: str, pronoun: str):
     return temp[tense_conj[pronoun] + 24]
 
 
+# Header conjugate: Branches to different methods
 def conjugate(verb: str, pronoun="alles", tense="present", get_all=False):
     # assert "*" not in verb
 
